@@ -17,6 +17,7 @@ class ArtistModel: AudioCollectionModel {
     var observable = Observable<MediaLibraryBaseModelObserver>()
 
     var files = [VLCMLArtist]()
+    var fileArrayLock = NSRecursiveLock()
 
     var cellType: BaseCollectionViewCell.Type {
         return UserDefaults.standard.bool(forKey: "\(kVLCAudioLibraryGridLayout)\(name)") ? MediaGridCollectionCell.self : MediaCollectionViewCell.self
@@ -29,16 +30,28 @@ class ArtistModel: AudioCollectionModel {
     var indicatorName: String = NSLocalizedString("ARTISTS", comment: "")
 
     required init(medialibrary: MediaLibraryService) {
+        defer {
+            fileArrayLock.unlock()
+        }
         self.medialibrary = medialibrary
         medialibrary.observable.addObserver(self)
+        fileArrayLock.lock()
         files = medialibrary.artists()
     }
 
     func append(_ item: VLCMLArtist) {
+        defer {
+            fileArrayLock.unlock()
+        }
+        fileArrayLock.lock()
         files.append(item)
     }
 
     private func addNewArtists(_ artists: [VLCMLArtist]) {
+        defer {
+            fileArrayLock.unlock()
+        }
+        fileArrayLock.lock()
         let newArtists = artists.filter() {
             for artist in files {
                 if artist.identifier() == $0.identifier() {
@@ -69,6 +82,10 @@ class ArtistModel: AudioCollectionModel {
 // MARK: - Sort
 extension ArtistModel {
     func sort(by criteria: VLCMLSortingCriteria, desc: Bool) {
+        defer {
+            fileArrayLock.unlock()
+        }
+        fileArrayLock.lock()
         files = medialibrary.artists(sortingCriteria: criteria, desc: desc)
         sortModel.currentSort = criteria
         sortModel.desc = desc
@@ -97,7 +114,9 @@ extension ArtistModel: MediaLibraryObserver {
 
     func medialibrary(_ medialibrary: MediaLibraryService,
                       didModifyArtistsWithIds artistsIds: [NSNumber]) {
-
+        defer {
+            fileArrayLock.unlock()
+        }
         let uniqueArtistsIds = Array(Set(artistsIds))
         var artists = [VLCMLArtist]()
 
@@ -109,6 +128,7 @@ extension ArtistModel: MediaLibraryObserver {
             artists.append(safeArtist)
         }
 
+        fileArrayLock.lock()
         files = swapModels(with: artists)
         addNewArtists(artists)
         filterGeneratedArtists()
@@ -118,6 +138,10 @@ extension ArtistModel: MediaLibraryObserver {
     }
 
     func medialibrary(_ medialibrary: MediaLibraryService, didDeleteArtistsWithIds artistsIds: [NSNumber]) {
+        defer {
+            fileArrayLock.unlock()
+        }
+        fileArrayLock.lock()
         files.removeAll {
             artistsIds.contains(NSNumber(value: $0.identifier()))
         }
@@ -127,6 +151,10 @@ extension ArtistModel: MediaLibraryObserver {
     }
 
     func medialibraryDidStartRescan() {
+        defer {
+            fileArrayLock.unlock()
+        }
+        fileArrayLock.lock()
         files.removeAll()
     }
 }
