@@ -133,6 +133,7 @@ extension NSNotification {
 class MediaLibraryService: NSObject {
     private static let databaseName: String = "medialibrary.db"
     private static let didForceRescan: String = "MediaLibraryDidForceRescan"
+    private var triedToRecoverFromInitializationErrorOnce = false
 
     private var didFinishDiscovery = false
 
@@ -225,7 +226,18 @@ private extension MediaLibraryService {
         case .alreadyInitialized:
             assertionFailure("MediaLibraryService: Medialibrary already initialized.")
         case .failed:
-            preconditionFailure("MediaLibraryService: Failed to setup medialibrary.")
+            if triedToRecoverFromInitializationErrorOnce == false {
+                triedToRecoverFromInitializationErrorOnce = true
+                do {
+                    APLog(String(format: "MediaLibraryService: Failed to setup medialibrary, trying to recover by deleting previous database (%@)", databasePath))
+                    try FileManager.default.removeItem(atPath: databasePath)
+                    setupMediaLibrary()
+                    return
+                } catch let error as NSError {
+                    APLog(String(format: "Failed to delete previous database (%@)", error.localizedDescription))
+                }
+            }
+            preconditionFailure("MediaLibraryService: Permanently failed to setup medialibrary.")
         case .dbCorrupted:
             medialib.clearDatabase(restorePlaylists: true)
             startMediaLibrary(on: documentPath)
@@ -279,7 +291,7 @@ private extension MediaLibraryService {
 
     func savePlaybackState(from player: PlaybackService) {
         let media: VLCMedia? = player.currentlyPlayingMedia
-        guard let mlMedia = fetchMedia(with: media?.url.absoluteURL) else {
+        guard let mlMedia = fetchMedia(with: media?.url?.absoluteURL) else {
             // we opened a url and not a local file
             return
         }
@@ -370,10 +382,15 @@ private extension MediaLibraryService {
         // for the user that can be created by deleting media from the Files app.
         // This could lead to disk space issues.
         // For now since we do not handle restoration, we delete the `.Trash` folder every time.
-         _ = try? FileManager.default.removeItem(atPath: documentPath + "/.Trash")
+        // Run this on a background queue to not block the main thread and have the app killed on launch for taking too long
+        DispatchQueue.global(qos: .userInitiated).async {
+            _ = try? FileManager.default.removeItem(atPath: documentPath + "/.Trash")
 
-        // Reload in order to make sure that there is no old artifacts left
-        reload()
+            DispatchQueue.main.async {
+                // Reload in order to make sure that there is no old artifacts left
+                self.reload()
+            }
+        }
     }
 }
 
