@@ -37,7 +37,7 @@ struct VideoPlayerSeek {
     static let shortSeek: Int = 10
 
     struct Swipe {
-        static let forward: Int = 10
+        static let forward: Int = 30
         static let backward: Int = 10
     }
 }
@@ -246,8 +246,6 @@ class VideoPlayerViewController: UIViewController {
     private var rendererButton: UIButton?
     let notificationCenter = NotificationCenter.default
 
-    private var resetOptionsOnNextPresentation: Bool = false
-
     private(set) lazy var titleSelectionView: TitleSelectionView = {
         let isLandscape = UIDevice.current.orientation.isLandscape
         let titleSelectionView = TitleSelectionView(frame: .zero,
@@ -303,6 +301,7 @@ class VideoPlayerViewController: UIViewController {
         let vc = BrightnessControlView()
         vc.updateIcon(level: brightnessControl.fetchAndGetDeviceValue())
         vc.translatesAutoresizingMaskIntoConstraints = false
+        vc.alpha = 0
         return vc
     }()
 
@@ -310,6 +309,7 @@ class VideoPlayerViewController: UIViewController {
         let vc = VolumeControlView(volumeView: self.volumeView)
         vc.updateIcon(level: volumeControl.fetchAndGetDeviceValue())
         vc.translatesAutoresizingMaskIntoConstraints = false
+        vc.alpha = 0
         return vc
     }()
 
@@ -601,12 +601,7 @@ class VideoPlayerViewController: UIViewController {
         // Media is loaded in the media player, checking the projection type and configuring accordingly.
         setupForMediaProjection()
 
-        // Checking if this is the first time that the controller appears.
-        // Reseting the options if necessary the first time unables the user to modify the video filters.
-        if resetOptionsOnNextPresentation {
-            moreOptionsActionSheet.resetOptionsIfNecessary()
-        }
-        resetOptionsOnNextPresentation = true
+        moreOptionsActionSheet.resetOptionsIfNecessary()
     }
 
     func setupRepeatModeButton() {
@@ -875,14 +870,15 @@ extension VideoPlayerViewController {
         let animations = { [weak self, playerController] in
             self?.mediaNavigationBar.alpha = uiComponentOpacity
             self?.optionsNavigationBar.alpha = uiComponentOpacity
-            self?.volumeControlView.alpha = playerController.isVolumeGestureEnabled ? 0 : uiComponentOpacity
-            self?.brightnessControlView.alpha = playerController.isBrightnessGestureEnabled ? 0 : uiComponentOpacity
+            self?.volumeControlView.alpha = playerController.isVolumeGestureEnabled ? uiComponentOpacity : 0
+            self?.brightnessControlView.alpha = playerController.isBrightnessGestureEnabled ? uiComponentOpacity : 0
             if !hidden || qvcHidden {
                 self?.videoPlayerControls.alpha = uiComponentOpacity
                 self?.scrubProgressBar.alpha = uiComponentOpacity
             }
             self?.backgroundGradientView.alpha = hidden && qvcHidden ? 0 : 1
         }
+
         let duration = animated ? 0.2 : 0
         UIView.animate(withDuration: duration, delay: 0,
                        options: .beginFromCurrentState, animations: animations,
@@ -1006,8 +1002,8 @@ extension VideoPlayerViewController {
         let panType = detectPanType(recognizer)
 
         guard panType == .projection
-                || playerController.isVolumeGestureEnabled
-                || playerController.isBrightnessGestureEnabled
+                || (panType == .volume && playerController.isVolumeGestureEnabled)
+                || (panType == .brightness && playerController.isBrightnessGestureEnabled)
         else {
             return
         }
@@ -1236,18 +1232,18 @@ private extension VideoPlayerViewController {
 
     private func videoPlayerButtons() {
         let audioMedia: Bool = playbackService.metadata.isAudioOnly
-        if view.frame.width >= DeviceWidth.iPhone12ProMaxPortrait.rawValue {
+        if audioMedia {
             videoPlayerControls.repeatButton.isHidden = false
             videoPlayerControls.shuffleButton.isHidden = false
 
+            videoPlayerControls.subtitleButton.isHidden = true
+            videoPlayerControls.aspectRatioButton.isHidden = true
+        } else {
+            videoPlayerControls.repeatButton.isHidden = true
+            videoPlayerControls.shuffleButton.isHidden = true
+
             videoPlayerControls.subtitleButton.isHidden = false
             videoPlayerControls.aspectRatioButton.isHidden = false
-        } else {
-            videoPlayerControls.repeatButton.isHidden = !audioMedia
-            videoPlayerControls.shuffleButton.isHidden = !audioMedia
-
-            videoPlayerControls.subtitleButton.isHidden = audioMedia
-            videoPlayerControls.aspectRatioButton.isHidden = audioMedia
         }
     }
     // MARK: - Constraints
@@ -1755,6 +1751,22 @@ extension VideoPlayerViewController: MediaMoreOptionsActionSheetDelegate {
             playbackService.playPause()
         }
     }
+
+    private func openOptionView(view: MediaPlayerActionSheetCellIdentifier) {
+        present(moreOptionsActionSheet, animated: true, completion: {
+            self.moreOptionsActionSheet.addView(view)
+        })
+    }
+
+    func mediaMoreOptionsActionSheetDidToggleShuffle(_ mediaMoreOptionsActionSheet: MediaMoreOptionsActionSheet) {
+        videoPlayerControlsDelegateShuffle(videoPlayerControls)
+        mediaMoreOptionsActionSheet.collectionView.reloadData()
+    }
+
+    func mediaMoreOptionsActionSheetDidTapRepeat(_ mediaMoreOptionsActionSheet: MediaMoreOptionsActionSheet) {
+        videoPlayerControlsDelegateRepeat(videoPlayerControls)
+        mediaMoreOptionsActionSheet.collectionView.reloadData()
+    }
 }
 
 // MARK: - OptionsNavigationBarDelegate
